Crate starbase_args

Crate starbase_args 

Structs

ArgsParser
Command
CommandLine
CommandList
Error
Parse-related error type.

Enums

Argument
ErrorVariant
Different kinds of parsing errors.
Expansion
InputLocation
Where an Error has occurred.
LineColLocation
Line/column where an Error has occurred.
Pipeline
Rule
Sequence
Substitution
Value

Functions

parse
parse_unquoted_value

Type Aliases

IsWhitespaceFn
Function mapping string element to bool denoting whether it’s a whitespace defined by user.
RuleToMessageFn
Function mapping rule to its helper message defined by user.