Structs
- Args
Parser - Command
- Command
Line - Command
List - Error
- Parse-related error type.
Enums
- Argument
- Error
Variant - Different kinds of parsing errors.
- Expansion
- Input
Location - Where an
Errorhas occurred. - Line
ColLocation - Line/column where an
Errorhas occurred. - Pipeline
- Rule
- Sequence
- Substitution
- Value
Functions
Type Aliases
- IsWhitespace
Fn - Function mapping string element to bool denoting whether it’s a whitespace defined by user.
- Rule
ToMessage Fn - Function mapping rule to its helper message defined by user.